testLed method
Led test
Test the specified led by turning it on. Two modes are available: 'fixed' and 'blink'. When 'fixed' mode is selected, the led stays on for 5 seconds. When 'blink' mode is selected, the led blinks 5 times in the specified interval (ms). The interval must be between 500 ms and 5000 ms. If not specified, the default value will be 1000 ms.
Parameters:
Implementation
Future<void> testLed({
String? uuidToken,
LedTest? ledTest,
}) async {
final response = await testLedWithHttpInfo(
uuidToken: uuidToken,
ledTest: ledTest,
);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
}